@@ -22,12 +22,12 @@
 (if (< emacs-major-version 23)
   (error "BBDB requires GNU Emacs 23 or later"))
 
-(defconst bbdb-version "3.1" "Version of BBDB.")
+(defconst bbdb-version "3.1.1" "Version of BBDB.")
 
-(defconst bbdb-version-date "2014-02-15 15:40:07-06:00"
+(defconst bbdb-version-date "2014-03-11 18:16:12-05:00"
   "Version date of BBDB.")
 
-(defcustom bbdb-print-tex-path '("/usr/local/share")
+(defcustom bbdb-print-tex-path '("/usr/local/share/bbdb")
   "List of directories with the BBDB tex files."
   :group 'bbdb-utilities-print
   :type '(repeat (directory :tag "Directory")))
